@@ -558,7 +558,7 @@ install_SL(){
     if [ -n "$(file $i | grep -iE "(Linux x86 kernel|Linux kernel x86 boot executable|x86 boot sector)")" ]; then
       # Ugly
       # we skip memtest, etherboot, freedos...
-      if [ -z "$(echo $i | grep -iE "(memtest|eb.zli|memdisk|gpxe.lkn|freedos|fdos)")" ]; then
+      if [ -z "$(echo $i | grep -iE "(memtest|eb.zli|memdisk|gpxe.lkn|ipxe.lkn|freedos|fdos)")" ]; then
         kernel="$i"
         break
       fi
